@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     EditionType,
@@ -155,7 +155,7 @@ _OptionalCreateNetworkInputRequestTypeDef = TypedDict(
     {
         "Description": str,
         "FrameworkConfiguration": "NetworkFrameworkConfigurationTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -188,7 +188,7 @@ _OptionalCreateNodeInputRequestTypeDef = TypedDict(
     "_OptionalCreateNodeInputRequestTypeDef",
     {
         "MemberId": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -221,7 +221,7 @@ _OptionalCreateProposalInputRequestTypeDef = TypedDict(
     "_OptionalCreateProposalInputRequestTypeDef",
     {
         "Description": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
     total=False,
 )
@@ -580,7 +580,7 @@ _OptionalMemberConfigurationTypeDef = TypedDict(
     {
         "Description": str,
         "LogPublishingConfiguration": "MemberLogPublishingConfigurationTypeDef",
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
         "KmsKeyArn": str,
     },
     total=False,
@@ -852,8 +852,8 @@ NodeTypeDef = TypedDict(
 ProposalActionsTypeDef = TypedDict(
     "ProposalActionsTypeDef",
     {
-        "Invitations": List["InviteActionTypeDef"],
-        "Removals": List["RemoveActionTypeDef"],
+        "Invitations": Sequence["InviteActionTypeDef"],
+        "Removals": Sequence["RemoveActionTypeDef"],
     },
     total=False,
 )
@@ -923,7 +923,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": Dict[str, str],
+        "Tags": Mapping[str, str],
     },
 )
 
@@ -931,7 +931,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
